/*
* Copyright (C) 2012 Chris Neasbitt
* Author: Chris Neasbitt
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 2 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
package edu.uga.cs.adblock;

import java.util.ArrayList;
import java.util.List;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import edu.uga.cs.json.JSONSerializable;

public class AdBlockRule extends JSONSerializable {

	private static final long serialVersionUID = -3078841771709740372L;
	private String regex;
	private List<String> options;
	private boolean exception;

	private static transient final Log log = LogFactory.getLog(AdBlockRule.class);

	public AdBlockRule(JSONObject jval) {
		super(jval);
		this.fromJSONObject(jval);
	}

	public AdBlockRule(String regex, List<String> options, boolean exception) {
		super(null);
		this.regex = regex;
		this.options = options;
		this.exception = exception;
	}

	@Override
	public void fromJSONObject(JSONObject jval) {
		this.regex = jval.optString("regex");
		this.options = new ArrayList<String>();
		JSONArray optarr = jval.optJSONArray("options");
		for (int i = 0; i < optarr.length(); i++) {
			this.options.add(optarr.optString(i));
		}

		this.exception = jval.optBoolean("exception");
	}

	@Override
	public JSONObject toJSONObject() {
		JSONObject retval = new JSONObject();
		try {
			retval.put("regex", this.regex);
			retval.put("options", this.options);
			retval.put("exception", this.exception);
		} catch (JSONException e) {
			if (log.isErrorEnabled()) {
				log.error("", e);
			}
		}
		return retval;
	}

	public String getRegex() {
		return this.regex;
	}

	public List<String> getOptions() {
		return this.options;
	}

	public boolean isException() {
		return this.exception;
	}

	@Override
	public String toString() {
		return this.toJSONString();
	}

}
