/*
* Copyright (C) 2013 Chris Neasbitt
* Author: Chris Neasbitt
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 2 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
package edu.uga.cs.clickminer.results;

//http://www2.cs.uregina.ca/~dbd/cs831/notes/confusion_matrix/confusion_matrix.html
public class ClassificationResult {
	private final double threshold;
	private final long truePositive, falsePositive, trueNegative, falseNegative;
	
	public ClassificationResult(double threshold, long truePositive, 
			long falsePositive, long trueNegative, long falseNegative){
		this.threshold = threshold;
		this.truePositive = truePositive;
		this.falsePositive = falsePositive;
		this.trueNegative = trueNegative;
		this.falseNegative = falseNegative;
	}

	public double getThreshold() {
		return threshold;
	}

	public long getTruePositive() {
		return truePositive;
	}

	public long getFalsePositive() {
		return falsePositive;
	}

	public long getTrueNegative() {
		return trueNegative;
	}

	public long getFalseNegative() {
		return falseNegative;
	}
	
	public double getSensitivity() {
		return truePositive / (double)(truePositive + falseNegative);
	}
	
	public double getTruePositiveRate() {
		return getSensitivity();
	}
	
	public double getRecall(){
		return getSensitivity();
	}
	
	public double getFalsePositiveRate(){
		return falsePositive / (double)(falsePositive + trueNegative);
	}
	
	public double getSpecificity() {
		return trueNegative / (double)(falsePositive + trueNegative);
	}
	
	public double getTrueNegativeRate(){
		return getSpecificity();
	}
	
	public double getFalseNegativeRate(){
		return falseNegative / (double)(truePositive + falseNegative);
	}
	
	public double getPrecision(){
		return truePositive / (double)(truePositive + falsePositive);
	}
	
	public double getAccuracy() {
		return truePositive + trueNegative / (double)(truePositive + 
				trueNegative + falsePositive + falseNegative);
	}
	
	public double getF1Measure(){
		return getFMeasure(1);
	}
	
	public double getF2Measure(){
		return getFMeasure(2);
	}
	
	public double getF05Measure(){
		return getFMeasure(0.5);
	}
	
	public double getFMeasure(double beta){
		double pre = this.getPrecision();
		double rec = this.getRecall();
		double beta2 = Math.pow(beta, 2);
		return (1 + beta2) * (pre * rec)/(beta2 * pre + rec);
	}
	
	public String toString(){
		return "Threshold: " + this.getThreshold() +
				" TruePositives: " + this.getTruePositive() +
				" FalsePositives: " + this.getFalsePositive() +
				" TrueNegatives: " + this.getTrueNegative() +
				" FalseNegatives: " + this.getFalseNegative();
	}
}
