/*
* Copyright (C) 2013 Chris Neasbitt
* Author: Chris Neasbitt
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 2 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
package edu.uga.cs.clickminer.results;

import java.util.ArrayList;
import java.util.List;

public class ComparisonSummary {
	private final int totalRecordedInteractions, matchableRecordedInteractions,
		matchableRecordedClicks, totalMinedInteractions, 
		totalMinedAddressBarInteractions, totalMinedFalsePositiveClicks, 
		minedMatchingPossibleClicks, minedMatchingPossibleNonClick, 
		minedMatchingClicks, minedMatchingNonClicks, confirmedClicks,
		unconfirmedClicks, augmentedClicks;

	public ComparisonSummary(int totalRecordedInteractions, int matchableRecordedInteractions,
			int matchableRecordedClicks, int totalMinedInteractions, 
			int totalMinedAddressBarInteractions, int totalMinedFalsePositiveClicks, 
			int minedMatchingPossibleClicks, int minedMatchingPossibleNonClick, 
			int minedMatchingClicks, int minedMatchingNonClicks, int confirmedClicks,
			int unconfirmedClicks, int augmentedClicks) {
		this.totalRecordedInteractions = totalRecordedInteractions;
		this.matchableRecordedInteractions = matchableRecordedInteractions;
		this.matchableRecordedClicks = matchableRecordedClicks;
		this.totalMinedInteractions = totalMinedInteractions;
		this.totalMinedAddressBarInteractions = totalMinedAddressBarInteractions;
		this.totalMinedFalsePositiveClicks = totalMinedFalsePositiveClicks;
		this.minedMatchingPossibleClicks = minedMatchingPossibleClicks;
		this.minedMatchingPossibleNonClick = minedMatchingPossibleNonClick;
		this.minedMatchingClicks = minedMatchingClicks;
		this.minedMatchingNonClicks = minedMatchingNonClicks;
		this.confirmedClicks = confirmedClicks;
		this.unconfirmedClicks = unconfirmedClicks;
		this.augmentedClicks = augmentedClicks;
	}

	public int getTotalRecordedInteractions() {
		return totalRecordedInteractions;
	}

	public int getMatchableRecordedInteractions() {
		return matchableRecordedInteractions;
	}

	public int getMatchableRecordedClicks() {
		return matchableRecordedClicks;
	}

	public int getTotalMinedInteractions() {
		return totalMinedInteractions;
	}

	public int getTotalMinedAddressBarInteractions() {
		return totalMinedAddressBarInteractions;
	}

	public int getTotalMinedFalsePositiveClicks() {
		return totalMinedFalsePositiveClicks;
	}

	public int getMinedMatchingPossibleClicks() {
		return minedMatchingPossibleClicks;
	}

	public int getMinedMatchingPossibleNonClick() {
		return minedMatchingPossibleNonClick;
	}

	public int getMinedMatchingClicks() {
		return minedMatchingClicks;
	}

	public int getMinedMatchingNonClicks() {
		return minedMatchingNonClicks;
	}
	
	public int getConfirmedClicks() {
		return confirmedClicks;
	}
	
	public int getUnconfirmedClicks() {
		return unconfirmedClicks;
	}
	
	public int getAugmentedClicks() {
		return augmentedClicks;
	}

	public List<String[]> toCSVData(){
		List<String[]> retval = new ArrayList<String[]>();
		String[] header = {"Total Recorded Interactions", 
				"Matchable Recorded Interactions",
				"Matchable Recorded Clicks", 
				"Total Mined Interactions",
				"Total Mined Address Bar Interactions",
				"Total Mined False Positive Clicks", //url and loc, no match
				"Mined Matching Possible Clicks",  //url, confirmed recorded
				"Mined Matching Possible Non-Click",  //url, unconfirmed recorded
				"Mined Matching Clicks", // url and loc, confirmed recorded
				"Mined Matching Non-Clicks", // url and loc, unconfirmed recorded
				"Confirmed Clicks",
				"Unconfirmed Clicks",
				"Augmented Clicks"};
		
		String[] data = new String[13];
		data[0] = Integer.toString(totalRecordedInteractions);
		data[1] = Integer.toString(matchableRecordedInteractions);
		data[2] = Integer.toString(matchableRecordedClicks);
		data[3] = Integer.toString(totalMinedInteractions);
		data[4] = Integer.toString(totalMinedAddressBarInteractions);
		data[5] = Integer.toString(totalMinedFalsePositiveClicks);
		data[6] = Integer.toString(minedMatchingPossibleClicks);
		data[7] = Integer.toString(minedMatchingPossibleNonClick);
		data[8] = Integer.toString(minedMatchingClicks);
		data[9] = Integer.toString(minedMatchingNonClicks);
		data[10] = Integer.toString(confirmedClicks);
		data[11] = Integer.toString(unconfirmedClicks);
		data[12] = Integer.toString(augmentedClicks);
		
		retval.add(header);
		retval.add(data);
		
		return retval;
	}

}
